@@ -96,6 +96,24 @@ BoolConfigData config_bool_common [] =
         N_("If this check is enabled, you can delete each letter."),
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_MODE,
+        SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_MODE_DEFAULT,
+        SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_MODE_DEFAULT,
+        N_("_Entering the pseudo ASCII input mode with capital letters."),
+        NULL,
+        N_("If this check is enabled, capital letters will becomes a trigger to enter the pseudo ASCII input mode."),
+        false,
+    },
+    {
+        SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_BLANK_BEHAVIOR,
+        SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_BLANK_BEHAVIOR_DEFAULT,
+        SCIM_ANTHY_CONFIG_ROMAJI_PSEUDO_ASCII_BLANK_BEHAVIOR_DEFAULT,
+        N_("Insert a _blank with a blank key."),
+        NULL,
+        N_("If this check is enabled, a blank key will works to insert a blank when entering the pseudo ASCII input mode."),
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT,
         SCIM_ANTHY_CONFIG_PREDICT_ON_INPUT_DEFAULT,
@@ -340,6 +358,16 @@ StringConfigData config_string_common [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_BEHAVIOR_ON_FOCUS_OUT,
+        SCIM_ANTHY_CONFIG_BEHAVIOR_ON_FOCUS_OUT_DEFAULT,
+        SCIM_ANTHY_CONFIG_BEHAVIOR_ON_FOCUS_OUT_DEFAULT,
+        N_("_Behavior on focus out:"),
+        NULL,
+        NULL,
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_LEFT_THUMB_SHIFT_KEY,
         SCIM_ANTHY_CONFIG_LEFT_THUMB_SHIFT_KEY_DEFAULT,
@@ -393,6 +421,19 @@ StringConfigData config_string_common [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_DICT_ENCODING,
+        SCIM_ANTHY_CONFIG_DICT_ENCODING_DEFAULT,
+        SCIM_ANTHY_CONFIG_DICT_ENCODING_DEFAULT,
+        N_("En_coding of dictionary:"),
+        NULL,
+        N_("If you choose \"EUC-JP-MS\", interoperatability of documents "
+           "created on this system with Microsoft Windows may improve, "
+           "but it depends on the implementation of your operating system "
+           "and actual encoding of your dictionary."),
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND,
         SCIM_ANTHY_CONFIG_DICT_ADMIN_COMMAND_DEFAULT,
@@ -537,6 +578,16 @@ StringConfigData config_keyboards_mode [] =
         NULL,
         false,
     },
+    {
+        SCIM_ANTHY_CONFIG_CANCEL_PSEUDO_ASCII_MODE_KEY,
+        SCIM_ANTHY_CONFIG_CANCEL_PSEUDO_ASCII_MODE_KEY_DEFAULT,
+        SCIM_ANTHY_CONFIG_CANCEL_PSEUDO_ASCII_MODE_KEY_DEFAULT,
+        N_("Pseudo ASCII mode cancel"),
+        N_("Select pseudo ASCII mode cancel key"),
+        N_("The key events to cancel the pseudo ASCII mode."),
+        NULL,
+        false,
+    },
     {
         SCIM_ANTHY_CONFIG_CIRCLE_TYPING_METHOD_KEY,
         SCIM_ANTHY_CONFIG_CIRCLE_TYPING_METHOD_KEY_DEFAULT,
@@ -1223,4 +1274,65 @@ ColorConfigData config_color_common [] =
         false,
     },
 };
+
+BoolConfigData *
+find_bool_config_entry (const char *config_key)
+{
+    if (!config_key)
+        return NULL;
+
+    for (unsigned int i = 0; config_bool_common[i].key; i++) {
+        BoolConfigData *entry = &config_bool_common[i];
+        if (entry->key && !strcmp (entry->key, config_key))
+            return entry;
+    }
+
+    return NULL;
+}
+
+IntConfigData *
+find_int_config_entry (const char *config_key)
+{
+    if (!config_key)
+        return NULL;
+
+    for (unsigned int i = 0; config_int_common[i].key; i++) {
+        IntConfigData *entry = &config_int_common[i];
+        if (entry->key && !strcmp (entry->key, config_key))
+            return entry;
+    }
+
+    return NULL;
+}
+
+StringConfigData *
+find_string_config_entry (const char *config_key)
+{
+    if (!config_key)
+        return NULL;
+
+    for (unsigned int i = 0; config_string_common[i].key; i++) {
+        StringConfigData *entry = &config_string_common[i];
+        if (entry->key && !strcmp (entry->key, config_key))
+            return entry;
+    }
+
+    return NULL;
+}
+
+ColorConfigData *
+find_color_config_entry (const char *config_key)
+{
+    if (!config_key)
+        return NULL;
+
+    for (unsigned int i = 0; config_color_common[i].fg_key; i++) {
+        ColorConfigData *entry = &config_color_common[i];
+        if (entry->fg_key && !strcmp (entry->fg_key, config_key))
+            return entry;
+    }
+
+    return NULL;
+}
+
 }
