@@ -80,6 +80,8 @@ public:
                                         = SCIM_ANTHY_STRING_HIRAGANA);
     String       get_raw               (unsigned int     start  = 0,
                                         int              length = -1);
+    bool         append                (const KeyEvent & key,
+                                        const String   & string);
     void         erase                 (unsigned int     start  = 0,
                                         int              length = -1,
                                         bool             allow_split = false);
@@ -104,6 +106,9 @@ public:
     bool         get_symbol_width      (void);
     void         set_number_width      (bool             half);
     bool         get_number_width      (void);
+    void         set_pseudo_ascii_mode (int              mode);
+    bool         is_pseudo_ascii_mode  (void);
+    void         reset_pseudo_ascii_mode (void);
 
 private:
     void         reset_pending         (void);
